package com.ruoyi.project.VRdemo.controller;

import java.io.IOException;
import java.util.ArrayList;
import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.alibaba.excel.EasyExcel;
import com.ruoyi.common.utils.excel.ExcelReadUtil;
import com.ruoyi.framework.aspectj.lang.annotation.Anonymous;
import com.ruoyi.project.VRdemo.domain.imData.ArchivesUnboundImData;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.framework.aspectj.lang.annotation.Log;
import com.ruoyi.framework.aspectj.lang.enums.BusinessType;
import com.ruoyi.project.VRdemo.domain.ArchivesUnbound;
import com.ruoyi.project.VRdemo.service.IArchivesUnboundService;
import com.ruoyi.framework.web.controller.BaseController;
import com.ruoyi.framework.web.domain.AjaxResult;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.framework.web.page.TableDataInfo;
import org.springframework.web.multipart.MultipartFile;

/**
 * 博雅集 Archives Unbound（Gale）Controller
 *
 * @author ruoyi
 * @date 2024-10-06
 */
@RestController
@RequestMapping("/vr/archivesUnbound")
public class ArchivesUnboundController extends BaseController {

    private final IArchivesUnboundService archivesUnboundService;

    public ArchivesUnboundController(@Autowired IArchivesUnboundService archivesUnboundService) {
        this.archivesUnboundService = archivesUnboundService;
    }

    /**
     * 查询博雅集 Archives Unbound（Gale）列表
     */
    @Anonymous
    @GetMapping("/list")
    public AjaxResult list(ArchivesUnbound archivesUnbound) {
        List<ArchivesUnbound> list = archivesUnboundService.selectArchivesUnboundList(archivesUnbound);

        AjaxResult ajaxResult = new AjaxResult();
        ajaxResult.put("code", 200);
        ajaxResult.put("rows", list);
        ajaxResult.put("total", list.size());
        return ajaxResult;
    }

    /**
     * 查询分页列表
     */
    @PreAuthorize("@ss.hasAnyRoles('admin,xmg')")
    @GetMapping("/pageList")
    public TableDataInfo pageList(ArchivesUnbound archivesUnbound) {
        startPage();
        List<ArchivesUnbound> list = archivesUnboundService.selectArchivesUnboundList(archivesUnbound);
        return getDataTable(list);
    }

    /**
     * 获取博雅集 Archives Unbound（Gale）详细信息
     */
    @Anonymous
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(archivesUnboundService.selectArchivesUnboundById(id));
    }

    /**
     * 新增博雅集 Archives Unbound（Gale）
     */
    @PreAuthorize("@ss.hasAnyRoles('admin,xmg')")
    @Log(title = "博雅集 Archives Unbound（Gale）", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody ArchivesUnbound archivesUnbound) {
        return toAjax(archivesUnboundService.insertArchivesUnbound(archivesUnbound));
    }

    /**
     * 修改博雅集 Archives Unbound（Gale）
     */
    @PreAuthorize("@ss.hasAnyRoles('admin,xmg')")
    @Log(title = "博雅集 Archives Unbound（Gale）", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody ArchivesUnbound archivesUnbound) {
        return toAjax(archivesUnboundService.updateArchivesUnbound(archivesUnbound));
    }

    /**
     * 删除博雅集 Archives Unbound（Gale）
     */
    @PreAuthorize("@ss.hasAnyRoles('admin,xmg')")
    @Log(title = "博雅集 Archives Unbound（Gale）", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(archivesUnboundService.deleteArchivesUnboundByIds(ids));
    }

    /**
     * 导出博雅集 Archives Unbound（Gale）列表
     */
    @PreAuthorize("@ss.hasAnyRoles('admin,xmg')")
    @Log(title = "博雅集 Archives Unbound（Gale）", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, ArchivesUnbound archivesUnbound) {
        List<ArchivesUnbound> list = archivesUnboundService.selectArchivesUnboundList(archivesUnbound);
        ExcelUtil<ArchivesUnbound> util = new ExcelUtil<>(ArchivesUnbound.class);
        util.exportExcel(response, list, "博雅集 Archives Unbound（Gale）数据");
    }

    /**
     * 下载导入模板
     */
    @Anonymous
    @PostMapping("/importTemplate")
    public void importTemplate(HttpServletResponse response) throws IOException {
        List<ArchivesUnboundImData> dataList = new ArrayList<>();
        EasyExcel.write(response.getOutputStream(), ArchivesUnboundImData.class).sheet("Sheet1").doWrite(dataList);
    }

    /**
     * 导入数据
     */
    @Anonymous
    @PostMapping("/import")
    public AjaxResult importData(MultipartFile file, boolean updateSupport) throws IOException {

        List<ArchivesUnbound> list = ExcelReadUtil.read(file, ArchivesUnboundImData.class, ArchivesUnbound.class);

        // 调用服务层方法进行数据导入处理
        String message = archivesUnboundService.importData(list, updateSupport);

        // 返回成功响应，携带导入结果信息
        return AjaxResult.success(message);
    }
}
