package com.ruoyi.project.VRdemo.controller;

import java.io.IOException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.alibaba.excel.EasyExcel;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.common.utils.excel.ExcelReadUtil;
import com.ruoyi.framework.aspectj.lang.annotation.Anonymous;
import com.ruoyi.project.VRdemo.domain.imData.RegionDevelopImData;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.framework.aspectj.lang.annotation.Log;
import com.ruoyi.framework.aspectj.lang.enums.BusinessType;
import com.ruoyi.project.VRdemo.domain.RegionDevelop;
import com.ruoyi.project.VRdemo.service.IRegionDevelopService;
import com.ruoyi.framework.web.controller.BaseController;
import com.ruoyi.framework.web.domain.AjaxResult;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.framework.web.page.TableDataInfo;
import org.springframework.web.multipart.MultipartFile;

/**
 * 东南亚地区发展报告Controller
 *
 * @author ruoyi
 * @date 2024-10-30
 */
@RestController
@RequestMapping("/vr/regionDevelop")
public class RegionDevelopController extends BaseController {

    private final IRegionDevelopService regionDevelopService;

    public RegionDevelopController(@Autowired IRegionDevelopService regionDevelopService) {
        this.regionDevelopService = regionDevelopService;
    }

    /**
     * 查询东南亚地区发展报告列表
     */
    @Anonymous
    @GetMapping("/list")
    public AjaxResult list(RegionDevelop regionDevelop) {
        List<HashMap<String, List<RegionDevelop>>> list = regionDevelopService.selectRegionDevelopListByMenu(regionDevelop);

        AjaxResult ajaxResult = new AjaxResult();
        ajaxResult.put("code", 200);
        ajaxResult.put("rows", list);
        return ajaxResult;
    }

    /**
     * 查询分页列表
     */
    @PreAuthorize("@ss.hasAnyRoles('admin,xmg')")
    @GetMapping("/pageList")
    public TableDataInfo pageList(RegionDevelop regionDevelop) {
        startPage();
        List<RegionDevelop> list = regionDevelopService.selectRegionDevelopList(regionDevelop);
        return getDataTable(list);
    }

    /**
     * 获取东南亚地区发展报告详细信息
     */
    @Anonymous
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(regionDevelopService.selectRegionDevelopById(id));
    }

    public RegionDevelop transformFile(RegionDevelop regionDevelop){
        //获取编号为00的文件路径
        String pathStr = regionDevelop.getPath();
        System.out.println(pathStr);
        String[] paths = pathStr.split(","); //将批量文件名转化为数组
        String zero = "";
        for (String s : paths) {
            String fileName = s.substring(s.lastIndexOf("/") + 1, s.lastIndexOf(".")); //获取文件名
            String last = fileName.substring(fileName.length() - 2); //获取文件名后面的编号
            if (last.equals("00")) {
                zero = s;
            }
        }
        System.out.println(zero);
        regionDevelop.setPath(zero);
        int count = paths.length;//获取上传文件数量
        regionDevelop.setCount((long) count);

        return regionDevelop;
    }

    /**
     * 新增东南亚地区发展报告
     */
    @PreAuthorize("@ss.hasAnyRoles('admin,xmg')")
    @Log(title = "东南亚地区发展报告", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody RegionDevelop regionDevelop) {
        if(!StringUtils.isNull(regionDevelop.getPath())){
            regionDevelop = transformFile(regionDevelop);
        }

        return toAjax(regionDevelopService.insertRegionDevelop(regionDevelop));
    }

    /**
     * 修改东南亚地区发展报告
     */
    @PreAuthorize("@ss.hasAnyRoles('admin,xmg')")
    @Log(title = "东南亚地区发展报告", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody RegionDevelop regionDevelop) {
        if(!StringUtils.isNull(regionDevelop.getPath())){
            regionDevelop = transformFile(regionDevelop);
        }
        return toAjax(regionDevelopService.updateRegionDevelop(regionDevelop));
    }

    /**
     * 删除东南亚地区发展报告
     */
    @PreAuthorize("@ss.hasAnyRoles('admin,xmg')")
    @Log(title = "东南亚地区发展报告", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(regionDevelopService.deleteRegionDevelopByIds(ids));
    }

    /**
     * 删除东南亚地区发展报告（包括文件）
     */
    @PreAuthorize("@ss.hasAnyRoles('admin,xmg')")
    @Log(title = "东南亚地区发展报告", businessType = BusinessType.DELETE)
    @DeleteMapping("/deleteFile/{id}")
    public String deleteFile(@PathVariable("id") Long id) {
        try {
            boolean success = regionDevelopService.deleteFile(id);
            if (success) {
                return "文件删除成功.";
            } else {
                return "文件删除失败.";
            }
        } catch (NumberFormatException e) {
            return "文件格式错误";
        }
    }


    /**
     * 导出东南亚地区发展报告列表
     */
    @PreAuthorize("@ss.hasAnyRoles('admin,xmg')")
    @Log(title = "东南亚地区发展报告", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, RegionDevelop regionDevelop) {
        List<RegionDevelop> list = regionDevelopService.selectRegionDevelopList(regionDevelop);
        ExcelUtil<RegionDevelop> util = new ExcelUtil<RegionDevelop>(RegionDevelop.class);
        util.exportExcel(response, list, "东南亚地区发展报告数据");
    }

    /**
     * 下载导入模板
     */
    @Anonymous
    @PostMapping("/importTemplate")
    public void importTemplate(HttpServletResponse response) throws IOException {
        List<RegionDevelopImData> dataList = new ArrayList<>();
        EasyExcel.write(response.getOutputStream(), RegionDevelopImData.class).sheet("Sheet1").doWrite(dataList);
    }

    /**
     * 导入数据
     */
    @Anonymous
    @PostMapping("/import")
    public AjaxResult importData(MultipartFile file, boolean updateSupport) throws IOException {

        List<RegionDevelop> list = ExcelReadUtil.read(file, RegionDevelopImData.class, RegionDevelop.class);

        // 调用服务层方法进行数据导入处理
        String message = regionDevelopService.importData(list, updateSupport);

        // 返回成功响应，携带导入结果信息
        return AjaxResult.success(message);
    }
}
