package com.ruoyi.project.VRdemo.service.impl;


import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;

import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.framework.web.domain.AjaxResult;
import com.ruoyi.project.VRdemo.domain.LibraryMenu;
import com.ruoyi.project.VRdemo.mapper.LibraryMenuMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.project.VRdemo.mapper.InstitutionMapper;
import com.ruoyi.project.VRdemo.domain.Institution;
import com.ruoyi.project.VRdemo.service.IInstitutionService;

/**
 * 博雅集东南亚研究机构Service业务层处理
 *
 * @author ruoyi
 * @date 2024-09-26
 */
@Service
public class InstitutionServiceImpl implements IInstitutionService {

    private final InstitutionMapper institutionMapper;

    private final LibraryMenuMapper libraryMenuMapper;

    public InstitutionServiceImpl(@Autowired InstitutionMapper institutionMapper, @Autowired LibraryMenuMapper libraryMenuMapper) {
        this.institutionMapper = institutionMapper;
        this.libraryMenuMapper = libraryMenuMapper;
    }

    /**
     * 查询博雅集东南亚研究机构
     *
     * @param id 博雅集东南亚研究机构主键
     * @return 博雅集东南亚研究机构
     */
    @Override
    public Institution selectInstitutionById(Long id) {
        return institutionMapper.selectInstitutionById(id);
    }

    /**
     * 查询博雅集东南亚研究机构列表
     *
     * @param institution 博雅集东南亚研究机构
     * @return 博雅集东南亚研究机构
     */
    @Override
    public List<Institution> selectInstitutionList(Institution institution) {
        return institutionMapper.selectInstitutionList(institution);
    }

    /**
     * 根据菜单查询博雅集东南亚研究机构列表
     *
     * @param institution 博雅集东南亚研究机构
     * @return 博雅集东南亚研究机构集合
     */
    @Override
    public List<HashMap<String, List<Institution>>> selectInstitutionListByMenu(Institution institution) {
        LibraryMenu parentMenu = libraryMenuMapper.selectLibraryMenuByModule("institution");
        List<LibraryMenu> menuList = libraryMenuMapper.selectChildMenuListById(parentMenu.getId());
        List<HashMap<String, List<Institution>>> list = new ArrayList<>();
        for (LibraryMenu menu : menuList){
            List<Institution> institutions = institutionMapper.selectInstitutionListByAffiliation(menu.getTitle());
            HashMap<String, List<Institution>> data = new HashMap<>();
            data.put(menu.getTitle(), institutions);
            list.add(data);
        }

        return list;
    }

    /**
     * 新增博雅集东南亚研究机构
     *
     * @param institution 博雅集东南亚研究机构
     * @return 结果
     */
    @Override
    public int insertInstitution(Institution institution) {
        institution.setCreateTime(DateUtils.getNowDate());
        return institutionMapper.insertInstitution(institution);
    }

    /**
     * 修改博雅集东南亚研究机构
     *
     * @param institution 博雅集东南亚研究机构
     * @return 结果
     */
    @Override
    public int updateInstitution(Institution institution) {
        institution.setUpdateTime(DateUtils.getNowDate());
        return institutionMapper.updateInstitution(institution);
    }

    /**
     * 批量删除博雅集东南亚研究机构
     *
     * @param ids 需要删除的博雅集东南亚研究机构主键
     * @return 结果
     */
    @Override
    public int deleteInstitutionByIds(Long[] ids) {
        return institutionMapper.deleteInstitutionByIds(ids);
    }

    /**
     * 删除博雅集东南亚研究机构信息
     *
     * @param id 博雅集东南亚研究机构主键
     * @return 结果
     */
    @Override
    public int deleteInstitutionById(Long id) {
        return institutionMapper.deleteInstitutionById(id);
    }

    /**
     * 导入数据
     */
    @Override
    public String importData(List<Institution> dataList, boolean updateSupport) {
        BulkImportService<Institution> importService = new BulkImportService<Institution>() {
            @Override
            protected Long checkExistingItem(Institution item) {
                Institution institution = institutionMapper.selectInstitutionByTitle(item.getChineseName(), item.getEnglishName());
                return institution == null ? 0L : institution.getId();
            }

            @Override
            protected boolean updateItem(Institution item, Long id) {
                item.setId(id);
                item.setUpdateBy(SecurityUtils.getLoginUser().getUsername());
                item.setUpdateTime(DateUtils.getNowDate());
                return institutionMapper.updateInstitution(item) > 0;
            }

            @Override
            protected boolean executeBatch(List<Institution> batchDataList) {
                return institutionMapper.insertInstitutionDataList(batchDataList) > 0;
            }

            @Override
            protected String getItemTitle(Institution item) {
                return item.getTitle();
            }
        };

        return importService.importData(dataList, updateSupport);
    }
}
