package com.ruoyi.project.VRdemo.service.impl;

import java.util.List;

import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.project.VRdemo.mapper.LibraryMenuMapper;
import com.ruoyi.project.VRdemo.domain.LibraryMenu;
import com.ruoyi.project.VRdemo.service.ILibraryMenuService;

/**
 * 南洋数字图书馆菜单管理Service业务层处理
 *
 * @author ruoyi
 * @date 2024-11-01
 */
@Service
public class LibraryMenuServiceImpl implements ILibraryMenuService {

    private final LibraryMenuMapper libraryMenuMapper;

    public LibraryMenuServiceImpl(@Autowired LibraryMenuMapper libraryMenuMapper) {
        this.libraryMenuMapper = libraryMenuMapper;
    }

    /**
     * 查询南洋数字图书馆菜单管理
     *
     * @param id 南洋数字图书馆菜单管理主键
     * @return 南洋数字图书馆菜单管理
     */
    @Override
    public LibraryMenu selectLibraryMenuById(Long id) {
        return libraryMenuMapper.selectLibraryMenuById(id);
    }

    /**
     * 查询南洋数字图书馆菜单管理列表
     *
     * @param libraryMenu 南洋数字图书馆菜单管理
     * @return 南洋数字图书馆菜单管理
     */
    @Override
    public List<LibraryMenu> selectLibraryMenuList(LibraryMenu libraryMenu) {
        return libraryMenuMapper.selectLibraryMenuList(libraryMenu);
    }

    /**
     * 根据父id查询南洋数字图书馆菜单管理列表
     *
     * @return 南洋数字图书馆菜单管理集合
     */
    @Override
    public List<LibraryMenu> selectMenuListByParentId(Long parentId) {
        return libraryMenuMapper.selectChildMenuListById(parentId);
    }

    /**
     * 新增南洋数字图书馆菜单管理
     *
     * @param libraryMenu 南洋数字图书馆菜单管理
     * @return 结果
     */
    @Override
    public int insertLibraryMenu(LibraryMenu libraryMenu) {
        if (libraryMenu.getParentId() == 17L){
            libraryMenu.setModule("region_develop_type");
        } else if (libraryMenu.getParentId() == 10L){
            libraryMenu.setModule("consultation_affiliation");
        }else if (libraryMenu.getParentId() == 14L){
            libraryMenu.setModule("economy_affiliation");
        }else if (libraryMenu.getParentId() == 11L){
            libraryMenu.setModule("institution_affiliation");
        }else if (libraryMenu.getParentId() == 15L){
            libraryMenu.setModule("publication_affiliation");
        }
        libraryMenu.setCreateTime(DateUtils.getNowDate());
        return libraryMenuMapper.insertLibraryMenu(libraryMenu);
    }

    /**
     * 修改南洋数字图书馆菜单管理
     *
     * @param libraryMenu 南洋数字图书馆菜单管理
     * @return 结果
     */
    @Override
    public int updateLibraryMenu(LibraryMenu libraryMenu) {
        libraryMenu.setUpdateTime(DateUtils.getNowDate());
        return libraryMenuMapper.updateLibraryMenu(libraryMenu);
    }

    /**
     * 批量删除南洋数字图书馆菜单管理
     *
     * @param ids 需要删除的南洋数字图书馆菜单管理主键
     * @return 结果
     */
    @Override
    public int deleteLibraryMenuByIds(Long[] ids) {
        return libraryMenuMapper.deleteLibraryMenuByIds(ids);
    }

    /**
     * 删除南洋数字图书馆菜单管理信息
     *
     * @param id 南洋数字图书馆菜单管理主键
     * @return 结果
     */
    @Override
    public int deleteLibraryMenuById(Long id) {
        return libraryMenuMapper.deleteLibraryMenuById(id);
    }

}
