package com.ruoyi.project.VRdemo.service.impl;

import java.time.LocalDate;
import java.time.format.DateTimeFormatter;
import java.util.ArrayList;
import java.util.Comparator;
import java.util.List;

import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.SecurityUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.project.VRdemo.mapper.LiteratureMapper;
import com.ruoyi.project.VRdemo.domain.Literature;
import com.ruoyi.project.VRdemo.service.ILiteratureService;

/**
 * 博雅集东南亚重要参考文献汇编Service业务层处理
 *
 * @author ruoyi
 * @date 2024-09-26
 */
@Service
public class LiteratureServiceImpl implements ILiteratureService {

    private final LiteratureMapper literatureMapper;

    public LiteratureServiceImpl(@Autowired LiteratureMapper literatureMapper) {
        this.literatureMapper = literatureMapper;
    }

    /**
     * 查询博雅集东南亚重要参考文献汇编
     *
     * @param id 博雅集东南亚重要参考文献汇编主键
     * @return 博雅集东南亚重要参考文献汇编
     */
    @Override
    public Literature selectLiteratureById(Long id) {
        return literatureMapper.selectLiteratureById(id);
    }

    /**
     * 按时间排序
     */
    public List<Literature> orderBYTime(List<Literature> literatureList){
        DateTimeFormatter formatter = DateTimeFormatter.ofPattern("yyyy年M月d日");

        List<Literature> sortedList = new ArrayList<>(literatureList);
        sortedList.sort(new Comparator<Literature>() {
            @Override
            public int compare(Literature o1, Literature o2) {
                LocalDate date1 = LocalDate.parse(o1.getPublicationTime(), formatter);
                LocalDate date2 = LocalDate.parse(o2.getPublicationTime(), formatter);
                return date2.compareTo(date1); // 倒序排列
            }
        });

        return sortedList;
    }

    /**
     * 查询博雅集东南亚重要参考文献汇编列表
     *
     * @param literature 博雅集东南亚重要参考文献汇编
     * @return 博雅集东南亚重要参考文献汇编
     */
    @Override
    public List<Literature> selectLiteratureList(Literature literature) {
        return literatureMapper.selectLiteratureList(literature);
    }

    /**
     * 按时间排序查询博雅集东南亚重要参考文献汇编列表
     *
     * @param literature 博雅集东南亚重要参考文献汇编
     * @return 博雅集东南亚重要参考文献汇编
     */
    @Override
    public List<Literature> selectLiteratureListOrderByTime(Literature literature) {
        List<Literature> literatureList = literatureMapper.selectLiteratureList(literature);

        return orderBYTime(literatureList);
    }

    /**
     * 新增博雅集东南亚重要参考文献汇编
     *
     * @param literature 博雅集东南亚重要参考文献汇编
     * @return 结果
     */
    @Override
    public int insertLiterature(Literature literature) {
        literature.setCreateTime(DateUtils.getNowDate());
        return literatureMapper.insertLiterature(literature);
    }

    /**
     * 修改博雅集东南亚重要参考文献汇编
     *
     * @param literature 博雅集东南亚重要参考文献汇编
     * @return 结果
     */
    @Override
    public int updateLiterature(Literature literature) {
        literature.setUpdateTime(DateUtils.getNowDate());
        return literatureMapper.updateLiterature(literature);
    }

    /**
     * 批量删除博雅集东南亚重要参考文献汇编
     *
     * @param ids 需要删除的博雅集东南亚重要参考文献汇编主键
     * @return 结果
     */
    @Override
    public int deleteLiteratureByIds(Long[] ids) {
        return literatureMapper.deleteLiteratureByIds(ids);
    }

    /**
     * 删除博雅集东南亚重要参考文献汇编信息
     *
     * @param id 博雅集东南亚重要参考文献汇编主键
     * @return 结果
     */
    @Override
    public int deleteLiteratureById(Long id) {
        return literatureMapper.deleteLiteratureById(id);
    }

    /**
     * 导入数据
     */
    @Override
    public String importData(List<Literature> dataList, boolean updateSupport) {
        BulkImportService<Literature> importService = new BulkImportService<Literature>() {
            @Override
            protected Long checkExistingItem(Literature item) {
                Literature literature = literatureMapper.selectLiteratureByTitle(item.getTitle());
                return literature == null ? 0L : literature.getId();
            }

            @Override
            protected boolean updateItem(Literature item, Long id) {
                item.setId(id);
                item.setUpdateBy(SecurityUtils.getLoginUser().getUsername());
                item.setUpdateTime(DateUtils.getNowDate());
                return literatureMapper.updateLiterature(item) > 0;
            }

            @Override
            protected boolean executeBatch(List<Literature> batchDataList) {
                return literatureMapper.insertLiteratureDataList(batchDataList) > 0;
            }

            @Override
            protected String getItemTitle(Literature item) {
                return item.getTitle();
            }
        };

        return importService.importData(dataList, updateSupport);
    }
}
