package com.ruoyi.project.VRdemo.service.impl;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;

import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.framework.web.domain.AjaxResult;
import com.ruoyi.project.VRdemo.domain.LibraryMenu;
import com.ruoyi.project.VRdemo.domain.Publication;
import com.ruoyi.project.VRdemo.mapper.LibraryMenuMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.project.VRdemo.mapper.PublicationMapper;
import com.ruoyi.project.VRdemo.service.IPublicationService;

/**
 * 东南亚连续出版物Service业务层处理
 *
 * @author ruoyi
 * @date 2024-10-06
 */
@Service
public class PublicationServiceImpl implements IPublicationService {

    private final PublicationMapper publicationMapper;

    private final LibraryMenuMapper libraryMenuMapper;

    public PublicationServiceImpl(@Autowired PublicationMapper publicationMapper, @Autowired LibraryMenuMapper libraryMenuMapper) {
        this.publicationMapper = publicationMapper;
        this.libraryMenuMapper = libraryMenuMapper;
    }

    /**
     * 查询东南亚连续出版物
     *
     * @param id 东南亚连续出版物主键
     * @return 东南亚连续出版物
     */
    @Override
    public Publication selectPublicationById(Long id) {
        return publicationMapper.selectPublicationById(id);
    }

    /**
     * 查询东南亚连续出版物列表
     *
     * @param publication 东南亚连续出版物
     * @return 东南亚连续出版物
     */
    @Override
    public List<Publication> selectPublicationList(Publication publication) {
        return publicationMapper.selectPublicationList(publication);
    }

    /**
     * 根据菜单查询东南亚连续出版物列表
     *
     * @param publication 东南亚连续出版物
     * @return 东南亚连续出版物集合
     */
    @Override
    public  List<HashMap<String, List<Publication>>> selectPublicationListByMenu(Publication publication) {
        LibraryMenu parentMenu = libraryMenuMapper.selectLibraryMenuByModule("publication");
        List<LibraryMenu> menuList = libraryMenuMapper.selectChildMenuListById(parentMenu.getId());
        List<HashMap<String, List<Publication>>> list = new ArrayList<>();
        for (LibraryMenu menu : menuList) {
            List<Publication> publications = publicationMapper.selectPublicationListByAffiliation(menu.getTitle());
            HashMap<String, List<Publication>> data = new HashMap<>();
            data.put(menu.getTitle(), publications);
            list.add(data);
        }

        return list;
    }

    /**
     * 新增东南亚连续出版物
     *
     * @param publication 东南亚连续出版物
     * @return 结果
     */
    @Override
    public int insertPublication(Publication publication) {
        publication.setCreateTime(DateUtils.getNowDate());
        return publicationMapper.insertPublication(publication);
    }

    /**
     * 修改东南亚连续出版物
     *
     * @param publication 东南亚连续出版物
     * @return 结果
     */
    @Override
    public int updatePublication(Publication publication) {
        publication.setUpdateTime(DateUtils.getNowDate());
        return publicationMapper.updatePublication(publication);
    }

    /**
     * 批量删除东南亚连续出版物
     *
     * @param ids 需要删除的东南亚连续出版物主键
     * @return 结果
     */
    @Override
    public int deletePublicationByIds(Long[] ids) {
        return publicationMapper.deletePublicationByIds(ids);
    }

    /**
     * 删除东南亚连续出版物信息
     *
     * @param id 东南亚连续出版物主键
     * @return 结果
     */
    @Override
    public int deletePublicationById(Long id) {
        return publicationMapper.deletePublicationById(id);
    }

    /**
     * 导入数据
     *
     * @param dataList      导入数据列表
     * @param updateSupport 是否更新已经存在的数据
     * @return 结果
     */
    @Override
    public String importData(List<Publication> dataList, boolean updateSupport) {
        BulkImportService<Publication> importService = new BulkImportService<Publication>() {
            @Override
            protected Long checkExistingItem(Publication item) {
                Publication publication = publicationMapper.selectPublicationByTitle(item.getTitle());
                return publication == null ? 0L : publication.getId();
            }

            @Override
            protected boolean updateItem(Publication item, Long id) {
                item.setId(id);
                item.setUpdateBy(SecurityUtils.getLoginUser().getUsername());
                item.setUpdateTime(DateUtils.getNowDate());
                return publicationMapper.updatePublication(item) > 0;
            }

            @Override
            protected boolean executeBatch(List<Publication> batchDataList) {
                return publicationMapper.insertPublicationDataList(batchDataList) > 0;
            }

            @Override
            protected String getItemTitle(Publication item) {
                return item.getTitle();
            }
        };

        return importService.importData(dataList, updateSupport);
    }
}
